# wpsrpc-sdk
WPS Office for Linux RPC API SDK

The C++ SDK headers was taken from [wps_cpp](https://code.aliyun.com/zouyingfeng/wps/tree/master/cpp) with *no changes*:
```
Copyright @ 2012-2019, Kingsoft office,All rights reserved.
```

The lib/x86_64 was extracted from [official package](https://wdl1.pcfg.cache.wpscdn.com/wpsdl/wpsoffice/download/linux/10702/wps-office_11.1.0.10702.XA_amd64.deb)
